(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('pdfjs-dist/es5/build/pdf')) :
	typeof define === 'function' && define.amd ? define(['exports', 'pdfjs-dist/es5/build/pdf'], factory) :
	(global = global || self, factory(global.VuePdfjsWrapper = {}, global.pdf));
}(this, (function (exports, pdf) { 'use strict';

	pdf = pdf && Object.prototype.hasOwnProperty.call(pdf, 'default') ? pdf['default'] : pdf;

	//
	//
	//
	//
	//
	//
	//

	var script = {
	  name: 'pdfPage',
	  props: {
	    pageNumber: {
	      type: Number,
	      required: true
	    },
	    page: {
	      type: Object,
	      required: true
	    },
	    scale: Number,
	    pageContainerID: String,
	    canvasID: String,
	    isRenderText: Boolean,
	    textLayerID: String
	  },
	  data: function data () {
	    return {
	      viewport: null
	    }
	  },
	  computed: {
	    getPageContainerID: function getPageContainerID () {
	      var idString = this.pageContainerID || 'pdf-page-container';
	      return idString + '-' + this.pageNumber
	    },
	    getCanvasID: function getCanvasID() {
	      var idString = this.canvasID || 'pdf-canvas-layer-page';
	      return idString + '-' + this.pageNumber
	    },
	    getTextLayerID: function getTextLayerID() {
	      var idString = this.textLayerID || 'pdf-text-layer-page';
	      return idString + '-' + this.pageNumber
	    }
	  },
	  methods: {
	    loadPage: async function loadPage() {
	      console.log('loading canvas layer');
	      var canvas = this.$refs[this.getCanvasID];
	      canvas.height = this.viewport.height;
	      canvas.width = this.viewport.width;
	      var context = canvas.getContext('2d');
	      var renderContext = {
	        canvasContext: context,
	        viewport: this.viewport
	      };
	      await this.page.render(renderContext);
	    },
	    loadTextLayer: async function loadTextLayer() {
	      console.log('loading text layer');
	      var div = this.$refs[this.getTextLayerID];
	      var textContent = await this.page.getTextContent();
	      var textLayer = this.$PDFJS.renderTextLayer({
	        container: div,
	        textContent: textContent,
	        viewport: this.viewport
	      });
	      textLayer._render();
	    }
	  },
	  created: function created () {
	    this.viewport = this.page.getViewport({ scale: this.scale });
	  },
	  mounted: async function mounted() {
	    await this.loadPage();
	    if (this.isRenderText) {
	      await this.loadTextLayer();
	    }
	  }
	};

	function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
	    if (typeof shadowMode !== 'boolean') {
	        createInjectorSSR = createInjector;
	        createInjector = shadowMode;
	        shadowMode = false;
	    }
	    // Vue.extend constructor export interop.
	    var options = typeof script === 'function' ? script.options : script;
	    // render functions
	    if (template && template.render) {
	        options.render = template.render;
	        options.staticRenderFns = template.staticRenderFns;
	        options._compiled = true;
	        // functional template
	        if (isFunctionalTemplate) {
	            options.functional = true;
	        }
	    }
	    // scopedId
	    if (scopeId) {
	        options._scopeId = scopeId;
	    }
	    var hook;
	    if (moduleIdentifier) {
	        // server build
	        hook = function (context) {
	            // 2.3 injection
	            context =
	                context || // cached call
	                    (this.$vnode && this.$vnode.ssrContext) || // stateful
	                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
	            // 2.2 with runInNewContext: true
	            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
	                context = __VUE_SSR_CONTEXT__;
	            }
	            // inject component styles
	            if (style) {
	                style.call(this, createInjectorSSR(context));
	            }
	            // register component module identifier for async chunk inference
	            if (context && context._registeredComponents) {
	                context._registeredComponents.add(moduleIdentifier);
	            }
	        };
	        // used by ssr in case component is cached and beforeCreate
	        // never gets called
	        options._ssrRegister = hook;
	    }
	    else if (style) {
	        hook = shadowMode
	            ? function (context) {
	                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
	            }
	            : function (context) {
	                style.call(this, createInjector(context));
	            };
	    }
	    if (hook) {
	        if (options.functional) {
	            // register for functional component in vue file
	            var originalRender = options.render;
	            options.render = function renderWithStyleInjection(h, context) {
	                hook.call(context);
	                return originalRender(h, context);
	            };
	        }
	        else {
	            // inject component registration as beforeCreate hook
	            var existing = options.beforeCreate;
	            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
	        }
	    }
	    return script;
	}

	/* script */
	var __vue_script__ = script;

	/* template */
	var __vue_render__ = function() {
	  var _vm = this;
	  var _h = _vm.$createElement;
	  var _c = _vm._self._c || _h;
	  return _c(
	    "div",
	    {
	      ref: _vm.getPageContainerID,
	      staticClass: "pdf-page-container",
	      attrs: { id: _vm.getPageContainerID }
	    },
	    [
	      _c("canvas", {
	        ref: _vm.getCanvasID,
	        staticClass: "pdf-canvas-layer",
	        attrs: { id: _vm.getCanvasID }
	      }),
	      _vm._v(" "),
	      _c("div", {
	        ref: _vm.getTextLayerID,
	        staticClass: "pdf-text-layer",
	        attrs: { id: _vm.getTextLayerID }
	      })
	    ]
	  )
	};
	var __vue_staticRenderFns__ = [];
	__vue_render__._withStripped = true;

	  /* style */
	  var __vue_inject_styles__ = undefined;
	  /* scoped */
	  var __vue_scope_id__ = undefined;
	  /* module identifier */
	  var __vue_module_identifier__ = undefined;
	  /* functional template */
	  var __vue_is_functional_template__ = false;
	  /* style inject */
	  
	  /* style inject SSR */
	  
	  /* style inject shadow dom */
	  

	  
	  var __vue_component__ = /*#__PURE__*/normalizeComponent(
	    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
	    __vue_inject_styles__,
	    __vue_script__,
	    __vue_scope_id__,
	    __vue_is_functional_template__,
	    __vue_module_identifier__,
	    false,
	    undefined,
	    undefined,
	    undefined
	  );

	//

	var script$1 = {
	  name: 'VuePdfjsWrapper',
	  components: { pdfPage: __vue_component__ },
	  props: {
	    pdfSrc: null,
	    scale: { type: Number, default: 1 },
	    isRenderText: Boolean
	  },
	  data: function data() {
	    return {
	      doc: null,
	      pages: []
	    }
	  },
	  methods: {
	    loadDocument: async function loadDocument() {
	      if (!this.pdfSrc) {
	        console.warn('Please give me a PDF file source to feed pdfjsLib.getDocument()');
	        return
	      }
	      this.pages = [];
	      var doc = await this.$PDFJS.getDocument(this.pdfSrc).promise;
	      this.doc = doc;
	      var pagesAmount = this.doc.numPages;
	      for (var pageNumber = 1; pageNumber <= pagesAmount; pageNumber++) {
	        var page = await doc.getPage(pageNumber);
	        page.pageNum = pageNumber;
	        this.pages.push(page);
	      }
	      this.$emit('loaded');
	    }
	  },
	  watch: {
	    pdfSrc: async function pdfSrc(value) {
	      if (value) {
	        this.loadDocument();
	      }
	    },
	    scale: async function scale() {
	      await this.loadDocument();
	    },
	    isRenderText: async function isRenderText() {
	      await this.loadDocument();
	    }
	  },
	  created: function created() {
	    if (this.pdfSrc) {
	      this.loadDocument();
	    }
	  }
	};

	var isOldIE = typeof navigator !== 'undefined' &&
	    /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());
	function createInjector(context) {
	    return function (id, style) { return addStyle(id, style); };
	}
	var HEAD;
	var styles = {};
	function addStyle(id, css) {
	    var group = isOldIE ? css.media || 'default' : id;
	    var style = styles[group] || (styles[group] = { ids: new Set(), styles: [] });
	    if (!style.ids.has(id)) {
	        style.ids.add(id);
	        var code = css.source;
	        if (css.map) {
	            // https://developer.chrome.com/devtools/docs/javascript-debugging
	            // this makes source maps inside style tags work properly in Chrome
	            code += '\n/*# sourceURL=' + css.map.sources[0] + ' */';
	            // http://stackoverflow.com/a/26603875
	            code +=
	                '\n/*# sourceMappingURL=data:application/json;base64,' +
	                    btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) +
	                    ' */';
	        }
	        if (!style.element) {
	            style.element = document.createElement('style');
	            style.element.type = 'text/css';
	            if (css.media)
	                { style.element.setAttribute('media', css.media); }
	            if (HEAD === undefined) {
	                HEAD = document.head || document.getElementsByTagName('head')[0];
	            }
	            HEAD.appendChild(style.element);
	        }
	        if ('styleSheet' in style.element) {
	            style.styles.push(code);
	            style.element.styleSheet.cssText = style.styles
	                .filter(Boolean)
	                .join('\n');
	        }
	        else {
	            var index = style.ids.size - 1;
	            var textNode = document.createTextNode(code);
	            var nodes = style.element.childNodes;
	            if (nodes[index])
	                { style.element.removeChild(nodes[index]); }
	            if (nodes.length)
	                { style.element.insertBefore(textNode, nodes[index]); }
	            else
	                { style.element.appendChild(textNode); }
	        }
	    }
	}

	/* script */
	var __vue_script__$1 = script$1;

	/* template */
	var __vue_render__$1 = function() {
	  var _vm = this;
	  var _h = _vm.$createElement;
	  var _c = _vm._self._c || _h;
	  return _c(
	    "div",
	    { ref: "pdf-pages-container", staticClass: "pdf-pages-container" },
	    _vm._l(_vm.pages, function(page) {
	      return _c("pdf-page", {
	        key: "pdf-canvas-layer-" + page.pageNum,
	        attrs: {
	          "page-number": page.pageNum,
	          page: page,
	          scale: _vm.scale,
	          "is-render-text": _vm.isRenderText
	        }
	      })
	    }),
	    1
	  )
	};
	var __vue_staticRenderFns__$1 = [];
	__vue_render__$1._withStripped = true;

	  /* style */
	  var __vue_inject_styles__$1 = function (inject) {
	    if (!inject) { return }
	    inject("data-v-fcd37072_0", { source: "\n.pdf-pages-container {\n  position: relative;\n  width: fit-content;\n}\n.pdf-page-container {\n  position: relative;\n  width: fit-content;\n}\n.pdf-text-layer {\n  position: absolute;\n  left: 0;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  overflow: hidden;\n  opacity: 0.2;\n  line-height: 1;\n}\n.pdf-text-layer > span {\n  color: transparent;\n  position: absolute;\n  white-space: pre;\n  cursor: text;\n  transform-origin: 0% 0%;\n}\n", map: {"version":3,"sources":["C:\\Users\\vingu\\Desktop\\Code_Stuff\\Vue\\vue-pdf-component\\src\\VuePdfjsWrapper.vue"],"names":[],"mappings":";AAqEA;EACA,kBAAA;EACA,kBAAA;AACA;AACA;EACA,kBAAA;EACA,kBAAA;AACA;AACA;EACA,kBAAA;EACA,OAAA;EACA,MAAA;EACA,QAAA;EACA,SAAA;EACA,gBAAA;EACA,YAAA;EACA,cAAA;AACA;AACA;EACA,kBAAA;EACA,kBAAA;EACA,gBAAA;EACA,YAAA;EACA,uBAAA;AACA","file":"VuePdfjsWrapper.vue","sourcesContent":["<template>\n  <div class=\"pdf-pages-container\" ref=\"pdf-pages-container\">\n    <pdf-page v-for=\"page in pages\"\n      :key=\"'pdf-canvas-layer-' + page.pageNum\"\n      :page-number=\"page.pageNum\"\n      :page=\"page\"\n      :scale=\"scale\"\n      :is-render-text=\"isRenderText\"\n    />\n  </div>\n</template>\n\n<script>\n  import pdfPage from './PdfPage.vue'\n\n  export default {\n    name: 'VuePdfjsWrapper',\n    components: { pdfPage },\n    props: {\n      pdfSrc: null,\n      scale: { type: Number, default: 1 },\n      isRenderText: Boolean\n    },\n    data() {\n      return {\n        doc: null,\n        pages: []\n      }\n    },\n    methods: {\n      async loadDocument() {\n        if (!this.pdfSrc) {\n          console.warn('Please give me a PDF file source to feed pdfjsLib.getDocument()')\n          return\n        }\n        this.pages = []\n        const doc = await this.$PDFJS.getDocument(this.pdfSrc).promise\n        this.doc = doc\n        const pagesAmount = this.doc.numPages\n        for (let pageNumber = 1; pageNumber <= pagesAmount; pageNumber++) {\n          const page = await doc.getPage(pageNumber)\n          page.pageNum = pageNumber\n          this.pages.push(page)\n        }\n        this.$emit('loaded')\n      }\n    },\n    watch: {\n      async pdfSrc(value) {\n        if (value) {\n          this.loadDocument()\n        }\n      },\n      async scale() {\n        await this.loadDocument()\n      },\n      async isRenderText() {\n        await this.loadDocument()\n      }\n    },\n    created() {\n      if (this.pdfSrc) {\n        this.loadDocument()\n      }\n    }\n  }\n</script>\n\n<style>\n  .pdf-pages-container {\n    position: relative;\n    width: fit-content;\n  }\n  .pdf-page-container {\n    position: relative;\n    width: fit-content;\n  }\n  .pdf-text-layer {\n    position: absolute;\n    left: 0;\n    top: 0;\n    right: 0;\n    bottom: 0;\n    overflow: hidden;\n    opacity: 0.2;\n    line-height: 1;\n  }\n  .pdf-text-layer > span {\n    color: transparent;\n    position: absolute;\n    white-space: pre;\n    cursor: text;\n    transform-origin: 0% 0%;\n  }\n</style>\n"]}, media: undefined });

	  };
	  /* scoped */
	  var __vue_scope_id__$1 = undefined;
	  /* module identifier */
	  var __vue_module_identifier__$1 = undefined;
	  /* functional template */
	  var __vue_is_functional_template__$1 = false;
	  /* style inject SSR */
	  
	  /* style inject shadow dom */
	  

	  
	  var __vue_component__$1 = /*#__PURE__*/normalizeComponent(
	    { render: __vue_render__$1, staticRenderFns: __vue_staticRenderFns__$1 },
	    __vue_inject_styles__$1,
	    __vue_script__$1,
	    __vue_scope_id__$1,
	    __vue_is_functional_template__$1,
	    __vue_module_identifier__$1,
	    false,
	    createInjector,
	    undefined,
	    undefined
	  );

	// Declare install function executed by Vue.use()
	function install(Vue, options) {
	  if ( options === void 0 ) options = {};

	  if (install.installed) { return }
	  install.installed = true;
	  // Installing pdfjsLib and setting its workerSrc to the CDN
	  // TODO: Review this
	  var workerSrc = options.workerSrc || ("//cdnjs.cloudflare.com/ajax/libs/pdf.js/" + (pdf.version) + "/pdf.worker.js");
	  pdf.GlobalWorkerOptions.workerSrc = workerSrc;
	  Object.defineProperty(Vue.prototype, '$PDFJS', { value: pdf });

	  Vue.component('vue-pdfjs-wrapper', __vue_component__$1);
	}

	// Create module definition for Vue.use()
	var plugin = { install: install };

	// Auto-install when vue is found (eg. in browser via <script> tag)
	var GlobalVue = null;
	if (typeof window !== 'undefined') {
	  GlobalVue = window.Vue;
	} else if (typeof global !== 'undefined') {
	  GlobalVue = global.Vue;
	}
	if (GlobalVue) {
	  GlobalVue.use(plugin);
	}

	exports.default = __vue_component__$1;
	exports.install = install;

	Object.defineProperty(exports, '__esModule', { value: true });

})));
